A new symmetric RSS rule may force another asymmetric rule to be
symmetric, vise versa. The reason is due to the flow engine will
try to reuse the existing profile if the input set matches with the
new rule. The fix is to disable this optimization for RSS since we
are not at the situation as profile shortage.

Fixes: ddae0440353f ("net/ice/base: enable symmetric hash for RSS")
Cc: sta...@dpdk.org

Signed-off-by: Qi Zhang <qi.z.zh...@intel.com>
---
 drivers/net/ice/base/ice_flex_pipe.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/drivers/net/ice/base/ice_flex_pipe.c 
b/drivers/net/ice/base/ice_flex_pipe.c
index 284569464..999ad6be3 100644
--- a/drivers/net/ice/base/ice_flex_pipe.c
+++ b/drivers/net/ice/base/ice_flex_pipe.c
@@ -2808,10 +2808,10 @@ ice_find_prof_id_with_mask(struct ice_hw *hw, enum 
ice_block blk,
        struct ice_es *es = &hw->blk[blk].es;
        u8 i;
 
        /* For FD, we don't want to re-use an existed profile with the same
         * field vector and mask. This will cause rule interference.
         */
-       if (blk == ICE_BLK_FD)
+       if (blk == ICE_BLK_FD || blk == ICE_BLK_RSS)
                return ICE_ERR_DOES_NOT_EXIST;
 
        for (i = 0; i < (u8)es->count; i++) {
@@ -2808,10 +2808,10 @@ ice_find_prof_id_with_mask(struct ice_hw *hw, enum 
        u8 i;
 
-       /* For FD, we don't want to re-use an existed profile with the same
-        * field vector and mask. This will cause rule interference.
+       /* For FD and RSS, we don't want to re-use an existed profile with the
+        * same field vector and mask. This will cause rule interference.
         */
-- 
2.13.6

Reply via email to